@@ -54,7 +54,8 @@ class BattleFieldView : public QGraphicsView
 
     Delegate *m_delegate;
     Sea::Player m_player;
-    
+    Sea::Status m_status;
+
     struct Preview {
         Coord pos;
         Ship* ship;
@@ -70,14 +71,18 @@ class BattleFieldView : public QGraphicsView
     
     typedef QMultiHash<Coord, Sprite*> Sprites;
     Sprites m_sprites;
+
+private:
     void addSprite(const Coord& c, Sprite* ship);
+    void loadPreviewSprite(Ship * ship);
+
 public:
     BattleFieldView(QWidget* parent, KBSRenderer* renderer, const QString& bgID, int gridSize);
 
     void toggleGrid(bool show);
     void refresh();
     
-    void setPreview(const QPointF& pos, Ship* ship);
+    void setPreview(const QPoint &pos);
     void cancelPreview();
     void add(Ship* ship);
     void hit(const Coord& c);
@@ -90,7 +95,7 @@ public:
     void setPlayer(Sea::Player player);
 
     WelcomeScreen* screen() const;
-
+    inline void setStatus(Sea::Status status) { m_status = status; };
 protected:
     void drawGrid();
 
