@@ -10,6 +10,7 @@
 #include "sprite.h"
 
 #include <kdebug.h>
+#include <QGraphicsEffect>
 
 #include "kbsrenderer.h"
 
@@ -26,6 +27,20 @@ Sprite::~Sprite()
 {
 }
 
+void Sprite::turnGreen()
+{
+    QGraphicsColorizeEffect * fx = new QGraphicsColorizeEffect();
+    fx->setColor(QColor(Qt::green));
+    setGraphicsEffect(fx);
+}
+
+void Sprite::turnRed()
+{
+    QGraphicsColorizeEffect * fx = new QGraphicsColorizeEffect();
+    fx->setColor(QColor(Qt::red));
+    setGraphicsEffect(fx);
+}
+
 void Sprite::refresh(KBSRenderer* renderer)
 {
     if (m_rotated)
